/* *************************************************************** dnd.c *** *
 * ɥå&ɥå״ؿ
 *
 * Copyright (C) 1998-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <05/05/05 18:36:51 sugaya>
 * ************************************************************************* */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "dnd.h"
#include "open.h"

/* ɥå׻Υ٥ **************************************************** */
static void
drop_event (GtkWidget		*widget,
	    GdkDragContext	*context,
	    gint		x,
	    gint		y,
	    GtkSelectionData	*selection_data,
	    guint		info,
	    guint		time) {
  gchar	*filename;

  if (!selection_data->data) return;

  filename = selection_data->data;
  filename[strlen (filename) - 2] = '\0';
  teoeyes_open_image_on_same_window (filename);
}
		     
/* ɥå¦ ******************************************************** */
void
dnd_drop_on_widget (GtkWidget	*widget) {
  static GtkTargetEntry drag_types[] = {
    {"text/uri-list", 0, 0},
    {"_NETSCAPE_URL", 0, 1}
  };
  static gint n_drag_types;

  n_drag_types = sizeof (drag_types) / sizeof (drag_types[0]);

  gtk_drag_dest_set (widget,
		     GTK_DEST_DEFAULT_MOTION |
		     GTK_DEST_DEFAULT_HIGHLIGHT |
		     GTK_DEST_DEFAULT_DROP,
		     drag_types,
		     n_drag_types,
		     GDK_ACTION_COPY);
  g_signal_connect (G_OBJECT (widget),
		    "drag_data_received", G_CALLBACK (drop_event), NULL);
}

/* ******************************************************** End of dnd.c *** */
